@@ -24,17 +24,21 @@ from horizon import tables
 from openstack_dashboard import policy
 from tacker_horizon.openstack_dashboard import api
 
+
 class VNFManagerItem(object):
-    def __init__(self, name, description, vnfs, status, stack_status, stack_id):
+
+    def __init__(self, name, description, vnfs, vim, status,
+                 stack_status, stack_id):
         self.name = name
         self.description = description
         self.vnfs = vnfs
+        self.vim = vim
         self.status = status
         self.stack_status = stack_status
         self.id = stack_id
 
 
-class VNFManagerItemList():
+class VNFManagerItemList(object):
     VNFLIST_P = []
 
     @classmethod
@@ -52,7 +56,6 @@ class VNFManagerItemList():
         cls.VNFLIST_P = []
 
 
-
 class MyFilterAction(tables.FilterAction):
     name = "myfilter"
 
@@ -89,8 +92,8 @@ class VNFUpdateRow(tables.Row):
 
     def get_data(self, request, vnf_id):
         try:
-            #stack = api.heat.stack_get(request, stack_id)
-            #if stack.stack_status == 'DELETE_COMPLETE':
+            # stack = api.heat.stack_get(request, stack_id)
+            # if stack.stack_status == 'DELETE_COMPLETE':
                 # returning 404 to the ajax call removes the
                 # row from the table on the ui
             #    raise Http404
@@ -98,7 +101,7 @@ class VNFUpdateRow(tables.Row):
             vnf_instance = api.tacker.get_vnf(request, vnf_id)
 
             if not vnf_instance and not item:
-                # TODO - bail with error
+                # TODO(NAME) - bail with error
                 return None
 
             if not vnf_instance and item:
@@ -115,15 +118,12 @@ class VNFUpdateRow(tables.Row):
             except KeyError:
                 vnf_desc_str = ""
 
+            vim = vnf['placement_attr']['vim_name']
             if not item:
                 # Add an item entry
-                item = VNFManagerItem(vnf['name'],
-                                     vnf_desc_str,
-                                     vnf_services_str,
-                                     vnf['status'],
-                                     vnf['status'],
-                                     vnf['id'])
-                #VNFManagerItemList.add_item(obj)
+                item = VNFManagerItem(vnf['name'], vnf_desc_str,
+                                      vnf_services_str, str(vim),
+                                      vnf['status'], vnf['status'], vnf['id'])
             else:
                 item.description = vnf_desc_str
                 item.vnfs = vnf_services_str
@@ -136,7 +136,8 @@ class VNFUpdateRow(tables.Row):
             messages.error(request, e)
             raise
 
-class DeleteServicesLink(policy.PolicyTargetMixin, tables.DeleteAction):
+
+class DeleteVNF(policy.PolicyTargetMixin, tables.DeleteAction):
     @staticmethod
     def action_present(count):
         return ungettext_lazy(
@@ -154,14 +155,15 @@ class DeleteServicesLink(policy.PolicyTargetMixin, tables.DeleteAction):
         )
 
     def action(self, request, obj_id):
-        api.tacker.delete_vnf(request,obj_id)
+        api.tacker.delete_vnf(request, obj_id)
 
-class AddServicesLink(tables.LinkAction):
-    name = "addservice"
+
+class DeployVNF(tables.LinkAction):
+    name = "deployvnf"
     verbose_name = _("Deploy VNF")
     classes = ("ajax-modal",)
     icon = "plus"
-    url = "horizon:nfv:vnfmanager:addservice"
+    url = "horizon:nfv:vnfmanager:deployvnf"
 
 
 class VNFManagerTable(tables.DataTable):
@@ -231,12 +233,13 @@ class VNFManagerTable(tables.DataTable):
         ("check_failed", pgettext_lazy("current status of stack",
                                        u"Check Failed")),
     )
-    name = tables.Column("name", \
+    name = tables.Column("name",
                          verbose_name=_("VNF Name"))
-    description = tables.Column("description", \
-                           verbose_name=_("Description"))
-    vnfs = tables.Column("vnfs", \
+    description = tables.Column("description",
+                                verbose_name=_("Description"))
+    vnfs = tables.Column("vnfs",
                          verbose_name=_("Deployed Services"))
+    vim = tables.Column("vim", verbose_name=_("VIM"))
     status = tables.Column("status",
                            hidden=True,
                            status=True,
@@ -245,9 +248,9 @@ class VNFManagerTable(tables.DataTable):
                                  verbose_name=_("Status"),
                                  display_choices=STACK_STATUS_DISPLAY_CHOICES)
 
-    class Meta:
+    class Meta(object):
         name = "vnfmanager"
         verbose_name = _("VNFManager")
-        status_columns = ["status",]
+        status_columns = ["status", ]
         row_class = VNFUpdateRow
-        table_actions = (AddServicesLink, DeleteServicesLink, MyFilterAction,)
+        table_actions = (DeployVNF, DeleteVNF, MyFilterAction,)
